import { createFilter } from 'rollup-pluginutils';
import istanbul from 'istanbul';

function index (options) {
	if ( options === void 0 ) options = {};

	var filter = createFilter(options.include, options.exclude);

	return {
		transform: function transform(code, id) {
		if (!filter(id)) return;

		var sourceMap = options.sourceMap !== false;
		var opts = Object.assign({}, options.instrumenterConfig);

		if (sourceMap) {
			opts.codeGenerationOptions = Object.assign({},
				opts.codeGenerationOptions || {format: {compact: !opts.noCompact}},
				{sourceMap: id, sourceMapWithCode: true}
			);
		}

		opts.esModules = true;
		var instrumenter = new (options.instrumenter || istanbul).Instrumenter(opts);

		code = instrumenter.instrumentSync(code, id);
		var map = sourceMap ?
			instrumenter.lastSourceMap().toJSON() :
		{mappings: ''};
		return {
			code: code,
			map: map
		};
	}
};
}

export default index;